Guides
======

.. toctree::
   :maxdepth: 2
   :caption: Contents:
   :hidden:

   guides/search.rst
   guides/archive.rst
   guides/local_ai.rst
   guides/ai_api_processing.rst
   guides/data_extraction.rst
   guides/feed_website_monitor.rst
   guides/authentication.rst
   guides/download.rst
   crawl_guidelines.rst
   guides/captcha.rst

🗂️ Search & Web Archiving
"""""""""""""""""""""""""

:doc:`guides/search`

:doc:`guides/archive`

🤖 AI-Powered Automation
""""""""""""""""""""""""

:doc:`guides/local_ai`

:doc:`guides/ai_api_processing`

🌐 Accessing and Interacting with Web Content
"""""""""""""""""""""""""""""""""""""""""""""

:doc:`guides/data_extraction`

:doc:`guides/feed_website_monitor`

:doc:`guides/authentication`

:doc:`guides/download`

⚖️ Ethics & Best Practices
""""""""""""""""""""""""""

:doc:`crawl_guidelines`

:doc:`guides/captcha`
